@@ -6,8 +6,7 @@ var config = {
     appKey: "next@2017",
     database: {
       host: 'rdb.codeunbug.com',
-      port: 28015,
-      db: 'oauth'
+      port: 28015
     },
 
     oauth: {
