@@ -11,7 +11,7 @@
 
 var session = require('express-session');
 var logger = require('winston');
-var logger = require('fs');
+var fs = require('fs');
 var RDBStore = require('./../datasource/rethinkdb-session')(session);
 const config = require(process.cwd() + '/config/config');
 var dbId=config.appId.replace(/-/g,"");
