@@ -12,12 +12,12 @@
 var bodyParser = require('body-parser');
 
 module.exports = function (app) {
-    // app.use(bodyParser.urlencoded({ extended: true }));
-    //  app.use(bodyParser.json());
+     app.use(bodyParser.urlencoded({ extended: true }));
+     app.use(bodyParser.json());
 
     //app.use(bodyParser.urlencoded({ extended: true }));
     //app.use(bodyParser.json());
-    app.use(/\/((?!graphql).)*/, bodyParser.urlencoded({ extended: true }));
-    app.use(/\/((?!graphql).)*/, bodyParser.json());
+   // app.use(/\/((?!graphql).)*/, bodyParser.urlencoded({ extended: true }));
+  //  app.use(/\/((?!graphql).)*/, bodyParser.json());
 
 }
\ No newline at end of file
