@@ -75,8 +75,8 @@ var oauth = {
   Login: function (callback) {
     var self = this;
     this._getParam();
-    this._setCookie("x_app_id", "{OAUTH_APP_ID}",1);
-    this._setCookie("x_app-key", "{OAUTH_APP_KEY}",1);
+    this._setCookie("x-app-id", "{OAUTH_APP_ID}",1);
+    this._setCookie("x-app-key", "{OAUTH_APP_KEY}",1);
     //var x_token=getResponseHeader
     console.log(this.urlParams.token);
     if (this.urlParams.token) {
